@@ -1,7 +1,5 @@
 package Text::Summarizer;
 
-our $VERSION = "1.02";
-
 use v5.10.0;
 use strict;
 use warnings;
@@ -10,6 +8,15 @@ use Types::Standard qw/ Ref Str Int Num InstanceOf /;
 use List::AllUtils qw/ max min sum singleton /;
 use utf8;
 
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
+require Exporter;
+
+@ISA = qw(Exporter);
+@EXPORT = qw();
+@EXPORT_OK = qw();
+%EXPORT_TAGS = (all => [@EXPORT_OK]);
+$VERSION = '1.0201';
+
 
 has permanent_path => (
 	is  => 'rw',
@@ -612,8 +619,11 @@ sub pretty_print {
 1;
 __END__
 
+	
 
-
+=pod
+ 
+=encoding utf-8
 
 =head1 NAME
 
